#
# spec file for package python-opentelemetry-instrumentation
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-opentelemetry-instrumentation
Version:        0.51b0
Release:        1.3
Summary:        Instrumentation Tools & Auto Instrumentation for OpenTelemetry Python
License:        Apache-2.0
URL:            https://github.com/open-telemetry/opentelemetry-python/tree/main/opentelemetry-instrumentation
Source:         https://files.pythonhosted.org/packages/source/o/opentelemetry-instrumentation/opentelemetry_instrumentation-%{version}.tar.gz
BuildRequires:  %{python_module packaging >= 18.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module opentelemetry-api >= 1.4}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wrapt >= 1.0.0}
# /SECTION
BuildRequires:  fdupes
Requires(post): update-alternatives
Requires(postun): update-alternatives
Requires:       python-opentelemetry-api >= 1.4
Requires:       python-wrapt >= 1.0.0
BuildArch:      noarch
%python_subpackages

%description
Instrumentation Tools & Auto Instrumentation for OpenTelemetry Python

%prep
%setup -q -n opentelemetry_instrumentation-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/opentelemetry-instrument
%python_clone -a %{buildroot}%{_bindir}/opentelemetry-bootstrap
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Tests disabled because they're not shipped with the sources
#%%check
#%%pytest

%post
%python_install_alternative opentelemetry-instrument opentelemetry-bootstrap

%postun
%python_uninstall_alternative opentelemetry-instrument

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/opentelemetry-instrument
%python_alternative %{_bindir}/opentelemetry-bootstrap
%{python_sitelib}/opentelemetry/instrumentation
%{python_sitelib}/opentelemetry_instrumentation-%{version}.dist-info

%changelog
* Tue Feb 25 2025 Dirk Müller <dmueller@suse.com>
- update to 0.51b0:
  * Always setup logs sdk,
    OTEL_PYTHON_LOGGING_AUTO_INSTRUMENTATION_ENABLED only
    controls python `logging` module handler setup
  * Add `attributes` field in `metrics.get_meter` wrapper
    function
  * Add Python 3.13 support
  * sdk: don't log or print warnings when the SDK has been
    disabled
  * Fix span context manager typing by using ParamSpec from
    typing_extensions
  * Fix serialization of None values in logs body to match
    1.31.0+ data model
  * [BREAKING] semantic-conventions: Remove `opentelemetry.semcon
    v.attributes.network_attributes.NETWORK_INTERFACE_NAME`
    introduced by mistake in the wrong module.
  * Add support for explicit bucket boundaries advisory for
    Histograms
  * semantic-conventions: Bump to 1.30.0
* Wed Jan  8 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.50b0
  * `opentelemetry-instrumentation-starlette` Add type hints to the instrumentation
  * `opentelemetry-distro` default to OTLP log exporter.
  * `opentelemetry-instrumentation-sqlalchemy` Update unit tests to run with SQLALchemy 2
  * Add `opentelemetry-instrumentation-openai-v2` to `opentelemetry-bootstrap`
  * `opentelemetry-instrumentation-sqlalchemy` Add sqlcomment to `db.statement` attribute
  * `opentelemetry-instrumentation-dbapi` Add sqlcomment to `db.statement` attribute
  * `opentelemetry-instrumentation-dbapi` instrument_connection accepts optional connect_module
  * `opentelemetry-instrumentation-mysqlclient` Add sqlcommenter support
  * `opentelemetry-instrumentation-pymysql` Add sqlcommenter support
  * `opentelemetry-instrumentation-click`: new instrumentation to trace click commands
  * `opentelemetry-instrumentation-starlette`: Retrieve `meter_provider` key instead of
    `_meter_provider` on `_instrument`
  * `opentelemetry-instrumentation-httpx`: instrument_client is a static method again
  * `opentelemetry-instrumentation-system_metrics`: fix callbacks reading wrong config
  * `opentelemetry-instrumentation-httpx`: Check if mount transport is none before wrap it
  * Replace all instrumentor unit test `assertEqualSpanInstrumentationInfo` calls with
    `assertEqualSpanInstrumentationScope` calls
  * `opentelemetry-instrumentation-sqlalchemy` Fixes engines from `sqlalchemy.engine_from_config`
    not being fully instrumented
  * `opentelemetry-instrumentation-sqlalchemy`: Fix a remaining memory leak in EngineTracer
  * `opentelemetry-instrumentation-sqlite3`: Update documentation on explicit cursor support of tracing
  * `opentelemetry-instrumentation-sqlalchemy` teach instruments version
  * Drop `opentelemetry-instrumentation-test` package from default instrumentation list
  * `opentelemetry-instrumentation-httpx`: remove private unused `_InstrumentedClient`
    and `_InstrumentedAsyncClient` classes
- from version 0.49b0
  * `opentelemetry-instrumentation-openai-v2` Instrumentation for OpenAI >= 0.27.0
  * `opentelemetry-instrumentation-fastapi` Add autoinstrumentation mechanism tests.
  * `opentelemetry-instrumentation-aiokafka` Add instrumentor and auto instrumentation
    support for aiokafka
  * `opentelemetry-instrumentation-redis` Add additional attributes for methods create_index
    and search, rename those spans
  * `opentelemetry-instrumentation` Add support for string based dotted module paths in unwrap
  * `opentelemetry-instrumentation-aiokafka` Wrap `AIOKafkaConsumer.getone()` instead of `AIOKafkaConsumer.__anext__`
  * `opentelemetry-instrumentation-confluent-kafka` Fix to allow `topic` to be extracted from `kwargs` in `produce()`
  * `opentelemetry-instrumentation-system-metrics` Update metric units to conform to UCUM conventions.
  * `opentelemetry-instrumentation-celery` Don't detach context without a None token
  * `opentelemetry-exporter-prometheus-remote-write`: sort labels before exporting
  * `opentelemetry-instrumentation-dbapi` sqlcommenter key values created from PostgreSQL, MySQL systems
  * `opentelemetry-instrumentation-system-metrics`: don't report open file descriptors on Windows
  * Deprecation of pkg_resource in favor of importlib.metadata
  * `opentelemetry-instrumentation` Don't fail distro loading if instrumentor raises ImportError, instead skip them
  * `opentelemetry-instrumentation-httpx` Rewrote instrumentation to use wrapt instead of subclassing
- Update BuildRequires from pyproject.toml
* Fri Aug 30 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.48b0
  * `opentelemetry-instrumentation-kafka-python` Instrument temporary fork,
    kafka-python-ng inside kafka-python's instrumentation (#2537)
  * `opentelemetry-bootstrap` Remove `opentelemetry-instrumentation-aws-lambda`
    from the defaults instrumentations (#2786)
  * `opentelemetry-instrumentation-httpx` fix handling of async hooks (#2823)
  * `opentelemetry-instrumentation-system-metrics` fix `process.runtime.cpu.utilization`
    values to be shown in range of 0 to 1 (#2812)
  * `opentelemetry-instrumentation-fastapi` fix `fastapi` auto-instrumentation by removing
    `fastapi-slim` support, `fastapi-slim` itself is discontinued from maintainers (#2783)
  * `opentelemetry-instrumentation-aws-lambda` Avoid exception when a handler is not present. (#2750)
  * `opentelemetry-instrumentation-django` Fix regression * `http.target`
    re-added back to old semconv duration metrics (#2746)
  * `opentelemetry-instrumentation-asgi` do not set `url.full` attribute for server spans (#2735)
  * `opentelemetry-instrumentation-grpc` Fixes the issue with the gRPC instrumentation
    not working with the 1.63.0 and higher version of gRPC (#2483)
  * `opentelemetry-instrumentation-aws-lambda` Fixing w3c baggage support (#2589)
  * `opentelemetry-instrumentation-celery` propagates baggage (#2385)
  * `opentelemetry-instrumentation-asyncio` Fixes async generator
    coroutines not being awaited (#2792)
  * `opentelemetry-instrumentation-tornado` Handle http client exception
    and record exception info into span (#2563)
  * `opentelemetry-instrumentation` fix `http.host` new http semantic
    convention mapping to depend on `kind` of span (#2814)
- for changes between 0.25b2 and 0.48b0 see upstream CHANGELOG.md
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
  * Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Limit Python files matched in %%files section
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
- Update BuildRequires from pyproject.toml
* Fri Nov  5 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.25b2
